"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.lambda = void 0;
const create = (module, opts) => __awaiter(void 0, void 0, void 0, function* () {
    var _a, _b, _c;
    const { NestFactory } = yield Promise.resolve().then(() => require('@nestjs/core'));
    if (opts.engine == 'fastify') {
        const { FastifyAdapter } = yield Promise.resolve().then(() => require('@nestjs/platform-fastify'));
        return NestFactory.create(module, new FastifyAdapter((_a = opts.fastify) === null || _a === void 0 ? void 0 : _a.options), (_b = opts.nestjs) === null || _b === void 0 ? void 0 : _b.options);
    }
    return yield NestFactory.create(module, (_c = opts.nestjs) === null || _c === void 0 ? void 0 : _c.options);
});
const init = (app, opts) => __awaiter(void 0, void 0, void 0, function* () {
    var _d, _e;
    if ((_d = opts.nestjs) === null || _d === void 0 ? void 0 : _d.onBeforeInit) {
        opts.nestjs.onBeforeInit(app);
    }
    yield app.init();
    if (opts.engine == 'fastify') {
        const instance = app.getHttpAdapter().getInstance();
        yield instance.ready();
    }
    if ((_e = opts.nestjs) === null || _e === void 0 ? void 0 : _e.onAfterInit) {
        opts.nestjs.onAfterInit(app);
    }
});
const bootstrap = (module, opts) => __awaiter(void 0, void 0, void 0, function* () {
    const app = yield create(module, opts);
    yield init(app, opts);
    return app;
});
const handleAPIGatewayProxyEvent = (app, event, context, opts) => __awaiter(void 0, void 0, void 0, function* () {
    var _f;
    if (opts.engine === 'fastify') {
        const { proxy } = yield Promise.resolve().then(() => require('aws-serverless-fastify'));
        return yield proxy(app.getHttpAdapter().getInstance(), event, context, ((_f = opts.fastify) === null || _f === void 0 ? void 0 : _f.binaryTypes) || []);
    }
    else {
        const { proxy, createServer } = yield Promise.resolve().then(() => require('aws-serverless-express'));
        return proxy(createServer(app.getHttpAdapter().getInstance()), event, context, 'PROMISE').promise;
    }
});
exports.lambda = (module, options) => {
    const opts = options ? options : { engine: 'express', warmup: { source: 'serverless-plugin-warmup' }, nestjs: {} };
    if (opts.fastify) {
        opts.fastify.binaryTypes = opts.fastify.binaryTypes || [];
    }
    if (!opts.nestjs) {
        opts.nestjs = {};
    }
    let cachedApp;
    return (event, context) => __awaiter(void 0, void 0, void 0, function* () {
        var _a;
        if ((event === null || event === void 0 ? void 0 : event.source) && (event === null || event === void 0 ? void 0 : event.source) === ((_a = opts === null || opts === void 0 ? void 0 : opts.warmup) === null || _a === void 0 ? void 0 : _a.source))
            return 'Lambda is warm!';
        if (event === null || event === void 0 ? void 0 : event.httpMethod) {
            if (!cachedApp) {
                cachedApp = yield bootstrap(module, opts);
            }
            return handleAPIGatewayProxyEvent(cachedApp, event, context, opts);
        }
    });
};
//# sourceMappingURL=index.js.map